==> mx-datetime_0.19.9.03.tar.xz: mx-datetime-0.19.9.03/translations/mx-datetime_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="575"/>
        <source>MX Date &amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="127"/>
        <source>Date &amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="195"/>
        <source>H:mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="281"/>
        <source>Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="287"/>
        <source>Hardware Clock tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="296"/>
        <source>Read the Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="316"/>
        <source>Time transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="322"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="325"/>
        <source>System Clock to Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="332"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="335"/>
        <source>Hardware Clock to System Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="345"/>
        <source>Time zone for the Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="358"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="401"/>
        <source>Network Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="407"/>
        <source>Move the selected item down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="418"/>
        <source>Move the selected item up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="429"/>
        <source>Remove the current item from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="440"/>
        <source>Add an item to the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="466"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="473"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="476"/>
        <source>Update Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="485"/>
        <source>List of NTP servers to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="501"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="506"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="511"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="160"/>
        <source>Reading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="211"/>
        <source>Updating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="218"/>
        <source>The system clock was updated successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="220"/>
        <source>The system clock could not be updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="222"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="574"/>
        <source>About MX Date &amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="575"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="576"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="578"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="579"/>
        <location filename="../datetime.cpp" line="593"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="580"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="581"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="607"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="626"/>
        <source>MX Date \&amp; Time Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>

==> mx-datetime_19.9.tar.xz: mx-datetime-19.9/translations/mx-datetime_ro.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="ro_RO">
<context>
    <name>MXDateTime</name>
    <message>
        <location filename="../datetime.ui" line="20"/>
        <location filename="../datetime.cpp" line="580"/>
        <source>MX Date &amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="26"/>
        <source>Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="40"/>
        <source>Help</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="73"/>
        <source>Apply</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="100"/>
        <source>About...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="124"/>
        <source>Date &amp;&amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="192"/>
        <source>H:mm:ss</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="278"/>
        <location filename="../datetime.cpp" line="282"/>
        <location filename="../datetime.cpp" line="286"/>
        <source>Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="284"/>
        <source>Hardware Clock tools</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="290"/>
        <source>Obtain information from the Hardware Clock and present it in the box below.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="293"/>
        <source>Read the Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="313"/>
        <source>Time transfer</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="319"/>
        <source>Immediately set the Hardware Clock to match the current time registered by the System Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="322"/>
        <source>System Clock to Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="329"/>
        <source>Immediately set the System Clock to match the current time registered by the Hardware Clock.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="332"/>
        <source>Hardware Clock to System Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="342"/>
        <source>Time zone for the Hardware Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="348"/>
        <source>Local time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="351"/>
        <source>Local</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="358"/>
        <source>Universally Coordinated Time (or Greenwich Meridian Time)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="361"/>
        <source>UTC</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="401"/>
        <source>Network Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="407"/>
        <source>Move the selected item down</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="418"/>
        <source>Move the selected item up</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="429"/>
        <source>Remove the current item from the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="440"/>
        <source>Add an item to the list</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="466"/>
        <source>Automatically update the System Clock with NTP servers:</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="473"/>
        <source>Immediately update the system clock with NTP servers.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="476"/>
        <source>Update Now</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="485"/>
        <source>List of NTP servers to use.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="501"/>
        <source>Type</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="506"/>
        <source>Address</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.ui" line="511"/>
        <source>Options</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="270"/>
        <source>Reading...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="282"/>
        <location filename="../datetime.cpp" line="286"/>
        <source>System Clock</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="292"/>
        <source>The %1 time was transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="295"/>
        <source>The %1 time could not be transferred to the %2.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="334"/>
        <source>Updating...</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="344"/>
        <source>The system clock was updated successfully.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="346"/>
        <source>The system clock could not be updated.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="348"/>
        <source>None of the NTP servers on the list are currently enabled.</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="579"/>
        <source>About MX Date &amp; Time</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="580"/>
        <source>Version: </source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="581"/>
        <source>GUI program for setting the time and date in MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="583"/>
        <source>Copyright (c) MX Linux</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="584"/>
        <location filename="../datetime.cpp" line="598"/>
        <source>License</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="585"/>
        <source>Changelog</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="586"/>
        <source>Cancel</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="612"/>
        <source>&amp;Close</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../datetime.cpp" line="630"/>
        <source>MX Date &amp; Time Help</source>
        <translation type="unfinished"></translation>
    </message>
</context>
</TS>
